==> jc-1.4.0.tar.gz: jas/UnsignedByteOperand.h <==
// class jas.UnsignedByteOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class e38a2d43aff37c34 jas_UnsignedByteOperand
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_UnsignedByteOperand_H_
#define _JC_jas_UnsignedByteOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_UnsignedByteOperand$sub_refs	_jc_jas_UnsignedByteOperand$sub_refs;
typedef struct _jc_jas_UnsignedByteOperand$sub_nonrefs	_jc_jas_UnsignedByteOperand$sub_nonrefs;
typedef struct _jc_jas_UnsignedByteOperand$refs	_jc_jas_UnsignedByteOperand$refs;
typedef struct _jc_jas_UnsignedByteOperand$nonrefs	_jc_jas_UnsignedByteOperand$nonrefs;
typedef struct _jc_jas_UnsignedByteOperand$object	_jc_jas_UnsignedByteOperand$object;

typedef const struct _jc_jas_UnsignedByteOperand$vmethods	_jc_jas_UnsignedByteOperand$vmethods;
typedef const struct _jc_jas_UnsignedByteOperand$vtable	_jc_jas_UnsignedByteOperand$vtable;
typedef const struct _jc_jas_UnsignedByteOperand$vtype	_jc_jas_UnsignedByteOperand$vtype;

// Constructors
extern void _jc_jas_UnsignedByteOperand$method$_init$7f1776288300b98d(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, jint);

// Virtual methods
extern void _jc_jas_UnsignedByteOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_UnsignedByteOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
extern void _jc_jas_UnsignedByteOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_UnsignedByteOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_UnsignedByteOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_UnsignedByteOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_UnsignedByteOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_UnsignedByteOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_UnsignedByteOperand$vmethods	jas_UnsignedByteOperand;
};

// Vtype
struct _jc_jas_UnsignedByteOperand$vtype {
	_jc_type			type;
	_jc_jas_UnsignedByteOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_UnsignedByteOperand$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_UnsignedByteOperand$refs {
    _jc_jas_UnsignedByteOperand$sub_refs	jas_UnsignedByteOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_UnsignedByteOperand$sub_nonrefs {
	jint	val;
};

// Non-reference instance fields (object)
struct _jc_jas_UnsignedByteOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_UnsignedByteOperand$sub_nonrefs	jas_UnsignedByteOperand;
};

// Object instance structure
struct _jc_jas_UnsignedByteOperand$object {
	_jc_jas_UnsignedByteOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_UnsignedByteOperand$vtype	*vtype;
	_jc_jas_UnsignedByteOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_UnsignedByteOperand$vtype _jc_jas_UnsignedByteOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_UnsignedByteOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_UnsignedByteOperand$class_object;

#endif	/* _JC_jas_UnsignedByteOperand_H_ */

==> jc-1.4.6.tar.gz: jas/UnsignedByteOperand.h <==
// class jas.UnsignedByteOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class e38a2d43aff37c34 jas_UnsignedByteOperand
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_UnsignedByteOperand_H_
#define _JC_jas_UnsignedByteOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_UnsignedByteOperand$sub_refs	_jc_jas_UnsignedByteOperand$sub_refs;
typedef struct _jc_jas_UnsignedByteOperand$sub_nonrefs	_jc_jas_UnsignedByteOperand$sub_nonrefs;
typedef struct _jc_jas_UnsignedByteOperand$refs	_jc_jas_UnsignedByteOperand$refs;
typedef struct _jc_jas_UnsignedByteOperand$nonrefs	_jc_jas_UnsignedByteOperand$nonrefs;
typedef struct _jc_jas_UnsignedByteOperand$object	_jc_jas_UnsignedByteOperand$object;

typedef const struct _jc_jas_UnsignedByteOperand$vmethods	_jc_jas_UnsignedByteOperand$vmethods;
typedef const struct _jc_jas_UnsignedByteOperand$vtable	_jc_jas_UnsignedByteOperand$vtable;
typedef const struct _jc_jas_UnsignedByteOperand$vtype	_jc_jas_UnsignedByteOperand$vtype;

// Constructors
extern void _jc_jas_UnsignedByteOperand$method$_init$7f1776288300b98d(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_UnsignedByteOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_UnsignedByteOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_UnsignedByteOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_UnsignedByteOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_UnsignedByteOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_UnsignedByteOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_UnsignedByteOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_UnsignedByteOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_UnsignedByteOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_UnsignedByteOperand$vmethods	jas_UnsignedByteOperand;
};

// Vtype
struct _jc_jas_UnsignedByteOperand$vtype {
	_jc_type			type;
	_jc_jas_UnsignedByteOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_UnsignedByteOperand$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_UnsignedByteOperand$refs {
    _jc_jas_UnsignedByteOperand$sub_refs	jas_UnsignedByteOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_UnsignedByteOperand$sub_nonrefs {
	jint	val;
};

// Non-reference instance fields (object)
struct _jc_jas_UnsignedByteOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_UnsignedByteOperand$sub_nonrefs	jas_UnsignedByteOperand;
};

// Object instance structure
struct _jc_jas_UnsignedByteOperand$object {
	_jc_jas_UnsignedByteOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_UnsignedByteOperand$vtype	*vtype;
	_jc_jas_UnsignedByteOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_UnsignedByteOperand$vtype _jc_jas_UnsignedByteOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_UnsignedByteOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_UnsignedByteOperand$class_object;

#endif	/* _JC_jas_UnsignedByteOperand_H_ */
